# stsci.stimage

[![Documentation Status](https://readthedocs.org/projects/stscistimage/badge/?version=latest)](https://stscistimage.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://dev.azure.com/spacetelescope/stsci.stimage/_apis/build/status/spacetelescope.stsci.stimage?branchName=master)](https://dev.azure.com/spacetelescope/stsci.stimage/_build/latest?definitionId=14&branchName=master)
[![codecov](https://codecov.io/gh/spacetelescope/stsci.stimage/branch/master/graph/badge.svg)](https://codecov.io/gh/spacetelescope/stsci.stimage)

Provides `xyxymatch` and `geomap`.
